clear all; clc;

fileID = fopen('demo_fin.txt','r');
formatSpec = '%f%f%[^\n\r]';
dataArray = textscan(fileID, formatSpec, 'Delimiter', '\t', 'EmptyValue' ,NaN, 'ReturnOnError', false);
fclose(fileID);

pop  = dataArray{:,1};
mort = dataArray{:,2};

clearvars fileID formatSpec dataArray ans;

age = [1:110]';

X = [age age.^2 age.^3 age.^4 age.^5 age.^6 age.^7 age.^8];

betahat = (X(1:85,:)'*X(1:85,:))\(X(1:85,:)'*mort(1:85));
morthat = X*betahat;

plot(mort); hold on; plot(morthat);

surv0 = 1-[mort(1:85); morthat(86:110) ];

possurv0 = surv0>0;
[x0, min0]=min(possurv0);

global Nv0 N0 gamv0 nag

nag  = min(min0);

gamv0 = surv0(1:(nag));
gamv0(nag) = 0;

Nv0 = zeros(nag,1);
N0  = 100;

% compute life expectancy
gamv02 = [gamv0;0]; lifeexpect  = 0;
for i=1:nag
    lifeexpect = lifeexpect + i*(1-gamv02(i+1))*prod(gamv02(1:i));
end
fprintf('LIFE EXPECT (MODEL): \t\t\t %4.5f\n',lifeexpect);

% DEMOGRAPHY
Nv0(1)   = 1;
for i=2:nag
    Nv0(i,1)= Nv0(i-1)*gamv0(i-1);
end
% rescale population
NB0 = 1/sum(Nv0)*N0;
Nv0 = Nv0/sum(Nv0)*N0;

fprintf('CHECK: POPULATION (MODEL): \t\t %4.5f\n',sum((1-gamv0).*Nv0)-NB0);

% rescale population data
global Nvdata

Nvdata = pop(1:nag)/sum(pop(1:nag))*100;

fprintf('IGNORED POPULATION (DATA): \t\t %4.5f pc\n',sum(pop((nag+1):size(pop,1)))/sum(pop(1:nag))*100);
fprintf('DEPENDENCY RATIO (MODEL): \t\t %4.5f\n',sum(Nv0(65:nag))/sum(Nv0(1:64)));
fprintf('DEPENDENCY RATIO (DATA): \t\t %4.5f\n',sum(Nvdata(65:nag))/sum(Nvdata(1:64)));

%plot([Nv0,Nvdata]);
bar([Nv0,Nvdata]);




